==> corporate_blue-7.x-1.0-alpha1.tar.gz: corporate_blue/templates/page.tpl.php <==
<div id="wrapper" class="container-12">
      <div class="header">
        <div class="grid-12">
          <div class="grid-4 alpha logo">
            <?php if ($site_name): ?>
                  <a href="<?php print check_url($front_page); ?>" title="<?php print t('Home'); ?>">
                    <img src="<?php print $logo; ?>" alt="<?php print $site_name; ?>" />
                  </a>
            <?php endif; ?>
          </div>
          <?php if ($page ['login']): ?>
          <div class="grid-8 omega">
            <?print render($page['login']); ?>
          </div>
          <?php endif; ?>
        </div>
      </div>
      <div class="grid-12  main_nav">
        <?php if ($page ['primarynav']): ?>
        <div class="grid-8 alpha omega">
          <?print render($page['primarynav']); ?>
        </div>
        <?php endif; ?>
        <?php if ($page ['search']): ?>
        <div class="grid-4">
          <?print render($page['search']); ?>
        </div>
        <?php endif; ?>
      </div>
      <div id="content_section" class="grid-12">
        <div class="grid-8 alpha region-content">
          <?php if ($page ['content']): ?>
    		        <?print render($page['content']); ?>
    			  <?php endif; ?>  
        </div>       
      
        <div class="grid-3 omega region-rightblock">
          <?php if ($page ['rightblockone']): ?>
            <?print render($page['rightblockone']); ?>
          <?php endif; ?>
          <?php if ($page ['rightblocktwo']): ?>
            <?print render($page['rightblocktwo']); ?>
          <?php endif; ?>
          <?php if ($page ['rightblockthree']): ?>
            <?print render($page['rightblockthree']); ?>
          <?php endif; ?>
          <?php if ($page ['rightblockfour']): ?>
            <?print render($page['rightblockfour']); ?>
          <?php endif; ?>
          <?php if ($page ['rightblockfive']): ?>
            <?print render($page['rightblockfive']); ?>
          <?php endif; ?>
        </div>
      </div>
      <div class="grid-12 footer_top">
        <?php if ($page ['f-left']): ?>
        <div class="grid-3 leftmargin">
          <?print render($page['f-left']); ?>
        </div>
        <?php endif; ?>
        <div class="grid-3">
        <?php if ($page ['f-middle']): ?>
        
          <div class="middle_top"></div>
          <div class="middle_middle"></div>
          <div class="middle_bottom"></div>
          <?print render($page['f-middle']); ?>
        
        <?php endif; ?>
        </div>
        <div class="grid-5">
        <?php if ($page ['f-right']): ?>
          <?print render($page['f-right']); ?>
        <?php endif; ?>       
        </div>
        <div class="footer_zyxware">Theme by <a href="http://www.zyxware.com/" title="Zyxware" target="_blank">Zyxware</a></div> 
      </div>
      <div class="grid-12 footer_bottom">
        <?php if ($page ['copyright']): ?>
          <?print render($page['copyright']); ?>
        <?php endif; ?> 
      </div> 
    </div>

==> corporate_blue-7.x-2.0-alpha1.tar.gz: corporate_blue/templates/page.tpl.php <==
<div id="wrapper" class="container-12">
      <div class="header">
        <div class="grid-12">
          <div class="grid-4 alpha logo">
            <?php if ($site_name): ?>
                  <a href="<?php print check_url($front_page); ?>" title="<?php print t('Home'); ?>">
                    <img src="<?php print $logo; ?>" alt="<?php print $site_name; ?>" />
                  </a>
            <?php endif; ?>
          </div>
          <?php if ($page ['login']): ?>
          <div class="grid-8 omega">
            <?php print render($page['login']); ?>
          </div>
          <?php endif; ?>
        </div>
      </div>
      <div class="grid-12  main_nav">
        <?php if ($page ['primarynav']): ?>
        <div class="grid-8 alpha omega">
          <?php print render($page['primarynav']); ?>
        </div>
        <?php endif; ?>
        <?php if ($page ['search']): ?>
        <div class="grid-4">
          <?php print render($page['search']); ?>
        </div>
        <?php endif; ?>
      </div>
      <div id="content_section" class="grid-12">
        <div class="grid-8 alpha region-content">
          <?php if ($tabs): ?>
            <?php print render($tabs); ?>
          <?php endif; ?>
          <?php if ($page ['content']): ?>
    		    <?php print render($page['content']); ?>
    			<?php endif; ?>  
        </div>       
      
        <div class="grid-3 omega region-rightblock">
          <?php if ($page ['rightblockone']): ?>
            <?php print render($page['rightblockone']); ?>
          <?php endif; ?>
          <?php if ($page ['rightblocktwo']): ?>
            <?php print render($page['rightblocktwo']); ?>
          <?php endif; ?>
          <?php if ($page ['rightblockthree']): ?>
            <?php print render($page['rightblockthree']); ?>
          <?php endif; ?>
          <?php if ($page ['rightblockfour']): ?>
            <?php print render($page['rightblockfour']); ?>
          <?php endif; ?>
          <?php if ($page ['rightblockfive']): ?>
            <?php print render($page['rightblockfive']); ?>
          <?php endif; ?>
        </div>
      </div>
      <div class="grid-12 footer_top">
        <?php if ($page ['f-left']): ?>
        <div class="grid-3 leftmargin">
          <?php print render($page['f-left']); ?>
        </div>
        <?php endif; ?>
        <div class="grid-3">
        <?php if ($page ['f-middle']): ?>
        
          <div class="middle_top"></div>
          <div class="middle_middle"></div>
          <div class="middle_bottom"></div>
          <?php print render($page['f-middle']); ?>
        
        <?php endif; ?>
        </div>
        <div class="grid-5">
        <?php if ($page ['f-right']): ?>
          <?php print render($page['f-right']); ?>
        <?php endif; ?>       
        </div>
        <div class="footer_zyxware">Theme by <a href="http://www.zyxware.com/" title="Zyxware" target="_blank">Zyxware</a></div> 
      </div>
      <div class="grid-12 footer_bottom">
        <?php if ($page ['copyright']): ?>
          <?php print render($page['copyright']); ?>
        <?php endif; ?> 
      </div> 
    </div>
